package
Version:
v0.0.0-...-70a5fc5
Opens a new window with list of versions in this module.
Published: Dec 1, 2025
License: GPL-3.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
Host string `mapstructure:"host"`
Port string `mapstructure:"port"`
User string `mapstructure:"user"`
Password string `mapstructure:"password"`
DBName string `mapstructure:"dbname"`
SSLMode string `mapstructure:"sslmode"`
MaxConns int32 `mapstructure:"max_conns"`
}
HealthCheck returns true if the database is reachable
Source Files
¶
Click to show internal directories.
Click to hide internal directories.